@@ -31,13 +31,12 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 module Data.Default (
 -- | This module defines a class for types with a default value. Instances are
--- provided for '()', 'S.Set', 'M.Map', 'Int', 'Integer', 'Float', 'Double',
--- and many others (see below).
+-- provided for '()', 'Data.Set.Set', 'Data.Map.Map', 'Int', 'Integer',
+-- 'Float', 'Double', and many others (see below).
     Default(..)
 ) where
 
 import Data.Default.Class
-import Data.Default.Instances.Base       ()
 import Data.Default.Instances.Containers ()
 import Data.Default.Instances.DList      ()
 import Data.Default.Instances.OldLocale  ()
